@@ -1,4 +1,5 @@
 import logging
+from pathlib import Path
 
 from mcgen.context import Context
 from mcgen.utils import summarize_registry
@@ -8,6 +9,6 @@ LOG = logging.getLogger(__name__)
 
 def process(ctx: Context, **options):
     """Create a summary of biome reports."""
-    registry_location = "reports/biomes"
-    LOG.info(f"Summarizing biomes at: {registry_location}")
-    summarize_registry(ctx, registry_location)
+    biomes_path = Path("reports/biomes")
+    LOG.info(f"Summarizing biomes at: {biomes_path}")
+    summarize_registry(ctx, biomes_path)
